%   Readme.m
%
%   This set of matlab routines draws various figures from the cruise data.
%
%   Routines that start with Do are driver routines that make one or more
%   plots and can save plots to postscript files.
%
%   SetupPlots.m defines information for a particular cruise.
%
%   the subdirectory matlab has a number of routines that make individual
%   figures but these are all called by scripts in this directory. 
%   almost all features of these routines are controlled by variables 
%   set in the driver or setup routines.
%
%   See Contents.m for a list of routines.
%
%   Use help <routine> in matlab to get a description of each routine. 
%   These descriptions are at the beginning of each routine. 
%

%   Variables used by these graphics programs.
%
%             variables used to control plots
%
%  DataDir        - A character string giving the top directory for the data.
%                   e.g. /disk/SOGLOBEC/CruiseData/
%  CruiseName     - A 7 character string giving the cruise name. 
%                   e.g., NBP0103, NBP0204
% DepthResolution -  a string set to OneMeter or StdDepth to indicate
%                    which data set to read.
%  Line           - A string of 4 characters to define a cluster of stations.
%                   e.g., grid, alls, x300, y180, etc.
%                   Choices are indicated in SetupPlots.m
%  FixGrid        - A flag to force recalculation of grid values based on lat,lon. 
%                   = 0, no recalculation,
%                   = 1, recalculate.

%  PlotCoast      -  a flag (0,1) to draw or not the coast on map plots.
%  ShadeCoast     -  a flag (0,1) to draw or not the filled contours 
%                    at zero depth on map plots.
%  PlotBathy      -  a flag (0,1) to contour or not the bathymetry.
%  MaskLand       -  a flag (0,1) to apply a land mask or not to variables on a map.


%  ctdcastlist    -  list of ctd casts to use in the plot.
%  xbtcastlist    -  list of xbt casts to use in the plot.
%  xctdcastlist   -  list of xctd casts to use in the plot.


%  UsePotTemp     -  a flag (0,1) to plot potential or insitu temperature.
%  UseDepth       -  a flag (0,1) to use depth or density to define surface 
%                    on which to plot.
%  Dens2Plot      -   density horizon for maps.
%  Depth2Plot     -  depth horizon for maps.
%  RefPress       -  reference pressure used for potential temperature or density.

%  xrange         - a 2-vector giving minimum and maximum x grid values for maps.
%  yrange         -  a 2-vector giving minimum and maximum y grid values for maps.
%  trange         -  a 2-vector giving minimum and maximum temperature values for plots.
%  srange         -  a 2-vector giving minimum and maximum salinity values for plots.
%  o2range        -  a 2-vector giving minimum and maximum oxygen values for plots.
%  sigrange       -  a 2-vector giving minimum and maximum density values for plots.
%  deprange       -  a 2-vector giving minimum and maximum depth values for plots.
%  botcl          -  isobaths to plot for maps with bottom topography.
%  cl             -  contour levels for plot being made (for both sections and maps).

%  MapNx          -  number of x points in the grid to contour random station values.
%  MapNy          -  number of y points in the grid to contour random station values.
%  MapMask        -  depth interpolated onto the above grid for use as a land mask.

%  SectionNx      -  max number of stations along a section.
%  SectionNz      -  number of depth points along a section.

%  Internal - 

%  figtitle -  title for figure.
%  InfoString -  informational message to plot on the plot.

% Internal Flags -  (set by routines)
%
%  GEOMINFO   - A flag to cause the coast and bathymetry files to be read.
%               = 0 is info not available. read files.
%               = 1 is info available. don't read files.
%  CRUISEINFO - A flag to cause the event files for a cruise to be read.
%               = 0 is info not available. read files.
%               = 1 is info available. don't read files.
%  DEFAULTS   - A flag to indicate if SetDefaults has been run. 
%               = 0 means SetDefaults has not been run. 
%               = 1 means SetDefaults has been run. 
%  MASKDONE   - A flag to indicate if the land mask has been created. 
%               = 0 means land mask has not been created.
%               = 1 means land mask has been created.
