%  Smap.m      - contour salinty on a given depth or density
%                level at horizontal locations on a regional map.
%
%   need variables set: ShadeCoast PlotCoast PlotBathy UseDepth Depth2Plot
%                       Dens2plot RefPress xrange yrange
%                       DataDir CruiseName DepthResolution
%   sets variables: none
%   calls: readctd swstate

global GEOMINFO CRUISEINFO DEFAULTS MASKDONE

%    title for figure
if(UseDepth == 1)
   zi=[-Depth2Plot -Depth2Plot];
   figtitle=['Salinity at ' num2str(Depth2Plot) ' m for ' CruiseName];
else
   RefPress=0;
   zi=[Dens2Plot Dens2Plot];
   figtitle=['Salinity on ' num2str(Dens2Plot) ' sigma for ' CruiseName];
end
%        open an new graphics window.
figure;
if(ShadeCoast)
   [Cc,hc]=contourf(xdep,ydep,zdep,[0 0]);
end
if(PlotCoast) 
   plot(xcoast,ycoast);
end
hold on;

if(PlotBathy) 
   [C,hc]=contour(xdep,ydep,zdep,botcl);
   %clabel(C,hc);
end
axis([xrange yrange]);
title(figtitle);
xlabel('distance (km)');
ylabel('distance (km)');

val=ones(size(ctdxgrid))*NaN;

Casts=0;
for cast=ctdcastlist
%           count number of casts
   Casts=Casts+1;
  file= [DataDir '/' CruiseName '/Ctd/' DepthResolution '/ctd' castnum(cast) '.dat'];

  [nlines,ndepths,desc,p,t,s,pt,r0,r1,bv,t0,t1,s0,s1,o2,par,tr,fl] = readctd(file);

%          convert pressure to depth
   Z=-p;
   CastDepth(cast)=max(p);
   X(cast)=ctdxgrid(cast);
   Y(cast)=ctdygrid(cast);
%                  reduce to 10 m resolution
   [m,n]=size(p);
   if(UseDepth == 1)
      if(isnan(s))
         val(cast)=NaN;
      else
         si=interp1(Z(1:10:m),s(1:10:m),zi,'linear');
         val(cast)=si(1);
      end
   else
      [SVAN,Pden]=swstate(s(1:10:m),pt(1:10:m),RefPress);
%        remove unstable densities by pushing values
%        deeper if next deeper value is less dense
%        add a small amount to have a vertical difference
      i=find(diff(Pden) <= 0);
      while  (~isempty(i))
         Pden(i+1)=Pden(i)+1.e-5;
         i=find(diff(Pden) <= 0);
      end
      if(isnan(s))
         val(cast)=NaN;
      else
         si=interp1(Pden,s(1:10:m),zi,'linear');
         val(cast)=si(1);
      end
   end
end

if xctdcastlist(1) == 0
   disp('No Xctd data')
else
%                 need to fix this part

  for cast=xctdcastlist
     file= ['XCTD' num2str(xcFileno(xccastlist(cast))) '.dat'];
%               read a profile of T, S
     [P,T,S]=readxctd(xcdatadir,file);
%          convert pressure to depth
     Z=-P;
     CastDepth(cast+casts)=max(P);
     X(cast+casts)=xcXloc(xccastlist(cast));
     Y(cast+casts)=xcYloc(xccastlist(cast));
%                  reduce to 10 m resolution
     [m,n]=size(P);
     if(UseDepth == 1)
        if(isnan(S))
           val(cast)=NaN;
        else
           si=interp1(Z(1:10:m),S(1:10:m),zi,'linear');
          val(cast)=si(1);
        end
     else
        [SVAN,Pden]=swstate(S(1:10:m),PT(1:10:m),RefPress);
%        remove unstable densities by pushing values
%        deeper if next deeper value is less dense
%        add a small amount to have a vertical difference
        i=find(diff(Pden) <= 0);
        while  (~isempty(i))
           Pden(i+1)=Pden(i)+1.e-5;
           i=find(diff(Pden) <= 0);
        end
        if(isnan(S))
           val(cast)=NaN;
        else
           si=interp1(Pden,S(1:10:m),zi,'linear');
           val(cast)=si(1);
        end
     end
  end
end

%           remove casts that are shallower than the plot depth
[nval i]=size(ctdxgrid);
i=find(CastDepth(1:nval) < Depth2Plot);
val(i)=NaN;

%quick  fix
%i=find( val < 30);
%val(i)=NaN;

xi=linspace(min(xrange),max(xrange),MapNx);
yi=linspace(min(yrange),max(yrange),MapNy);
[Xi,Yi]=meshgrid(xi,yi);
i=find(~isnan(val(1:nval)));
Vali=griddata(X(i),Y(i),val(i),Xi,Yi);

plot(X(i),Y(i),'r*')

if MaskLand == 1
%            mask grid values over land
  if MaskDone == 1
    [m n]= size(MapMask);
    if n ~= MapNx | m ~= MapNy
%         map not on same grid as MapNx, MapNy
%         need to recalculate the map
       MaskDone=0;
    end
  end
%      
  if MaskDone == 0
     disp(' Making land mask.')
     MapMask=griddata(xdep,ydep,zdep,Xi,Yi);
     MaskDone = 1
  end
  i=find( MapMask >  0);
  Vali(i)=NaN;
end

[C,hc]=contour(Xi,Yi,Vali,cl);
clabel(C,hc);

hold off;

%               print values to a file
%fid=fopen('Sal50.asc','w')
%for cast=1:Casts
%   fprintf(fid,'%9.4f  %9.4f  %9.6f \n',Lat(cast),Lon(cast),val(cast));
%end 
%fclose(fid)

drawnow

%    end of Smap.m



